@@ -29,12 +29,19 @@ Catalyst::AttrContainer
 
 =head1 DESCRIPTION
 
+This class sets up the code attribute cache.  It's a base class for 
+L<Catalyst::Base>
+
 =head1 METHODS
 
 =head2 FETCH_CODE_ATTRIBUTES
 
+Attribute function. See attributes(3pm)
+
 =head2 MODIFY_CODE_ATTRIBUTES
 
+Attribute function. See attributes(3pm)
+
 =head1 SEE ALSO
 
 L<Catalyst>.
